pub struct GlobalClusterGpuSettings {
pub initial_z_slice_list_capacity: usize,
pub initial_index_list_capacity: usize,
}Expand description
Settings relating to GPU clustering.
Fields
initial_z_slice_list_capacity: usizeThe initial capacity of the list of Z slices.
If there are too many clusterable objects on screen, this can overflow. Bevy will detect this situation and resize it, but you might see a few incorrect frames before Bevy resizes the list. To avoid this issue, you can set this to a higher value.
The default value is
bevy::pbr::cluster::GPU_CLUSTERING_INITIAL_Z_SLICE_LIST_SIZE.
initial_index_list_capacity: usizeThe initial capacity of the list of clusterable objects.
If there are too many clusterable objects on screen, this can overflow. Bevy will detect this situation and resize it, but you might see a few incorrect frames before Bevy resizes the list. To avoid this issue, you can set this to a higher value.
The default value is
bevy::pbr::cluster::GPU_CLUSTERING_INITIAL_INDEX_LIST_CAPACITY.